#include <Wire.h>
#include <ADXL345.h>
#include <Servo.h>
#include <math.h>


#define DEVICE_A (0x1D)    //first ADXL345 device address
#define DEVICE_B (0x53)    //second ADXL345 device address
#define TO_READ (6)        //num of bytes we are going to read each time (two bytes for each axis)


Servo servo1;
Servo servo2;
int pinServo1 = 3;
int pinServo2 = 5;


int led1;
int led2;
int regAddress = 0x32;      //first axis-acceleration-data register on the ADXL345
double x = 0, y = 0, z = 0;  
double j = 0, k = 0, l = 0;


byte buff[TO_READ] ;      //6 bytes buffer for saving data read from the device
char str[512];            //string buffer to transform data before sending it to the serial port

void writeTo(int device, byte address, byte val) {
   Wire.beginTransmission(device); //start transmission to device 
   Wire.write(address);        // send register address
   Wire.write(val);        // send value to write
   Wire.endTransmission(); //end transmission
}

void readFrom(int device, byte address, int num, byte buff[]) {
  Wire.beginTransmission(device); //start transmission to device 
  Wire.write(address);        //sends address to read from
  Wire.endTransmission(); //end transmission
  
  Wire.beginTransmission(device); //start transmission to device
  Wire.requestFrom(device, num);    // request 6 bytes from device
  
  int i = 0;
  while(Wire.available())    //device may send less than requested (abnormal)
  { 
    buff[i] = Wire.read(); // receive a byte
    i++;
  }
  Wire.endTransmission(); //end transmission
}

void setup(){

  Wire.begin();
  Serial.begin(9600);
  writeTo(DEVICE_A, 0x2D, 24);
  writeTo(DEVICE_B, 0x2D, 24);
  
  led1 = 12;
  led2 = 13;
  pinMode(led1, OUTPUT);
  digitalWrite(led1, LOW);
  
  pinMode(led2, OUTPUT);
  digitalWrite(led2, LOW);

  servo1.attach(pinServo1);
  servo2.attach(pinServo2);
  pinMode(pinServo1, OUTPUT);
  pinMode(pinServo2, OUTPUT);
}

void loop(){
  int mode = 0;
  if (Serial.available()) {
      // Check for input and assign the input to a variable
      int inputMessage = Serial.read();
      
        if(inputMessage == 8){ //Mode appli
             mode = 2;
        }
        if(inputMessage == 7){ //Mode capteurs
             mode = 1;
        }
      while(mode == 2){
        inputMessage = Serial.read();
        if(inputMessage == 15){  
             servo1.write(120);
             servo2.write(0);
             //digitalWrite(led1, HIGH);
             Serial.println("o");
        }

        if(inputMessage == 6){
             servo1.write(0);
             servo2.write(120);
             digitalWrite(led2, HIGH);
             Serial.println("f");
        }
                
        if(inputMessage == 9){
             mode = 0;
        }
      }
       
  while(mode == 1){

      inputMessage = Serial.read();  
      readFrom(DEVICE_A, regAddress, TO_READ, buff);  
      x = (((int)buff[1]) << 8) | buff[0];   
      y = (((int)buff[3])<< 8) | buff[2];
      z = (((int)buff[5]) << 8) | buff[4];

      readFrom(DEVICE_B, regAddress, TO_READ, buff); //read the acceleration data from the second ADXL345
      j = (((int)buff[1]) << 8) | buff[0];   
      k = (((int)buff[3])<< 8) | buff[2];
      l = (((int)buff[5]) << 8) | buff[4];
              

      double xAngle = atan( x / (sqrt(square(y) + square(z))));
      double yAngle = atan( y / (sqrt(square(x) + square(z))));
      double zAngle = atan( sqrt(square(x) + square(y)) / z);
 
      xAngle *= 180.00;   yAngle *= 180.00;   zAngle *= 180.00;
      xAngle /= 3.141592; yAngle /= 3.141592; zAngle /= 3.141592;

      double jAngle = atan( j / (sqrt(square(k) + square(l))));
      double kAngle = atan( k / (sqrt(square(j) + square(l))));
      double lAngle = atan( sqrt(square(j) + square(k)) / l);
 
      jAngle *= 180.00;   kAngle *= 180.00;   lAngle *= 180.00;
      jAngle /= 3.141592; kAngle /= 3.141592; lAngle /= 3.141592;

      int g = (int) jAngle;
      int h = (int) kAngle;
      int i = (int) lAngle;
      
              //Capteur 1
      if( z > 210){
          digitalWrite(led1,HIGH); 
          servo1.write(120);
          servo2.write(0);
      }
              
      if(z < 210){  
          digitalWrite(led1,LOW); 
          servo1.write(0);
          servo2.write(120);
      }
            
              //Capteur 2
      if(80 < g < 90){
          digitalWrite(led2,HIGH); 
          servo1.write(120);
          servo2.write(0);
      } 
              
      if(l > -50){
          digitalWrite(led2,LOW); 
          servo1.write(0);
          servo2.write(120);
      }

      if(inputMessage == 9){
           mode = 0;
      }

  //sprintf(str, "x = %d y = %d z = %d \nj = %d k = %d l = %d \n\n", x, y, z, j, k, l);  
  //Serial.print(str);
  //Serial.print(jAngle);
  //Serial.println("angle j = ");
  Serial.write(g);
 
  /*Serial.println("\nangle k = ");
  Serial.println(h);
  Serial.println("\nangle l = ");
  Serial.println(i);*/
  //Serial.write(10);
  
  }
  
  }
  delay(15);
}

